//@line 36 "/builds/slave/tm-lnx-mb-ntly/build/mobile/locales/en-US/mobile-l10n.js"

//@line 38 "/builds/slave/tm-lnx-mb-ntly/build/mobile/locales/en-US/mobile-l10n.js"

pref("general.useragent.locale", "en-US");
